@@ -2,15 +2,18 @@ import os
 import traceback
 import warnings
 from pathlib import Path
-from typing import Any, Dict, IO, Optional, Union
+from typing import Any, Dict, IO, Union
 
 from marshmallow import ValidationError
 
-from .io_ import load_raw_resource_description, resolve_rdf_source, save_raw_resource_description
+from .collection.v0_2.utils import resolve_collection_entries
+from .io_ import (
+    load_raw_resource_description,
+    resolve_rdf_source,
+    save_raw_resource_description,
+)
 from .shared.common import ValidationWarning, nested_default_dict_as_nested_dict
 
-KNOWN_COLLECTION_CATEGORIES = ("collection", "dataset", "model", "notebook", "rdf")
-
 
 def update_format(
     rdf_source: Union[dict, os.PathLike, IO, str, bytes],
@@ -75,42 +78,26 @@ def validate(
                 tb = traceback.format_tb(e.__traceback__)
 
             if raw_rd is not None and raw_rd.type == "collection":
-                for inner_category in KNOWN_COLLECTION_CATEGORIES:
-                    for inner_idx, inner in enumerate(getattr(raw_rd, inner_category, []) or []):
-                        # inner is CollectionEntry or RDF
-                        inner_source = getattr(inner, "source", None)
-                        inner_id = getattr(inner, "id", None)
+                assert hasattr(raw_rd, "collection")
+                for idx, (rdf_data, entry_error) in enumerate(resolve_collection_entries(raw_rd)):  # type: ignore
+                    if entry_error:
+                        entry_summary = {"error": entry_error}
+                    else:
+                        entry_summary = validate(
+                            rdf_data, update_format=update_format, update_format_inner=update_format_inner
+                        )
 
-                        if inner_id is not None:
-                            # expect that inner.source points to an rdf as only CollectionEntry has 'id' field
-                            try:
-                                rdf_data, source_name, root = resolve_rdf_source(inner_source)
-                            except Exception as e:
-                                inner_summary: Dict[str, Union[str, dict]] = {
-                                    "error": (
-                                        f"{inner_category}[{inner_idx}]: (id={inner_id}) Failed to interpret source as rdf source; error {e}"
-                                    )
-                                }
-                            else:
-                                # update rdf data with additional fields of the collection entry
-                                rdf_data.update(getattr(inner, "unknown", {}))
-                                inner_summary = validate(
-                                    rdf_data, update_format=update_format, update_format_inner=update_format_inner
-                                )
+                        wrns: Union[str, dict] = entry_summary.get("warnings", {})
+                        assert isinstance(wrns, dict)
+                        id_info = f"(id={rdf_data['id']}) " if "id" in rdf_data else ""
+                        for k, v in wrns.items():
+                            warnings.warn(f"collection[{idx}]:{k}: {id_info}{v}", category=ValidationWarning)
 
-                                wrns = inner_summary.get("warnings", {})
-                                assert isinstance(wrns, dict)
-                                for k, v in wrns.items():
-                                    warnings.warn(
-                                        f"{inner_category}[{inner_idx}]:{k}: (id={inner_id}) {v}",
-                                        category=ValidationWarning,
-                                    )
+                    if entry_summary["error"]:
+                        if "collection" not in nested_errors:
+                            nested_errors["collection"] = {}
 
-                            if inner_summary["error"]:
-                                if inner_category not in nested_errors:
-                                    nested_errors[inner_category] = {}
-
-                                nested_errors[inner_category][inner_idx] = inner_summary["error"]
+                        nested_errors["collection"][idx] = entry_summary["error"]
 
                 if nested_errors:
                     error = nested_errors
