@@ -21,7 +21,9 @@ try:
 except ImportError:
     from typing_extensions import Literal, get_args  # type: ignore
 
-FormatVersion = Literal["0.2.0", "0.2.1"]  # newest format needs to be last (used to determine latest format version)
+FormatVersion = Literal[
+    "0.2.0", "0.2.1", "0.2.2"
+]  # newest format needs to be last (used to determine latest format version)
 
 
 @dataclass(init=False)
@@ -31,9 +33,15 @@ class Attachments(RawNode):
     files: Union[_Missing, List[Union[Path, URI]]] = missing
     unknown: Dict[str, Any] = missing
 
-    def __init__(self, files: Union[_Missing, List[Union[Path, URI]]] = missing, **unknown):
+    def __init__(
+        self,
+        files: Union[_Missing, List[Union[Path, URI]]] = missing,
+        unknown: Dict[str, Any] = missing,
+        **implicitly_unknown,
+    ):
         self.files = files
-        self.unknown = unknown
+        self.unknown = unknown or {}
+        self.unknown.update(implicitly_unknown)
         super().__init__()
 
 
@@ -73,20 +81,23 @@ class Badge(RawNode):
 @dataclass
 class RDF(ResourceDescription):
     attachments: Union[_Missing, Attachments] = missing
-    authors: List[Author] = missing
+    authors: Union[_Missing, List[Author]] = missing
     badges: Union[_Missing, List[Badge]] = missing
-    cite: List[CiteEntry] = missing
+    cite: Union[_Missing, List[CiteEntry]] = missing
     config: Union[_Missing, dict] = missing
     covers: Union[_Missing, List[Union[URI, Path]]] = missing
     description: str = missing
-    documentation: Path = missing
+    documentation: Union[_Missing, Path, URI] = missing
+    download_url: Union[_Missing, URI] = missing
     format_version: FormatVersion = missing
     git_repo: Union[_Missing, str] = missing
+    id: Union[_Missing, str] = missing
     icon: Union[_Missing, str] = missing
     license: Union[_Missing, str] = missing
     links: Union[_Missing, List[str]] = missing
     maintainers: Union[_Missing, List[Maintainer]] = missing
-    tags: List[str] = missing
+    rdf_source: Union[_Missing, URI] = missing
+    tags: Union[_Missing, List[str]] = missing
 
     # manual __init__ to allow for unknown kwargs
     def __init__(
@@ -99,18 +110,22 @@ class RDF(ResourceDescription):
         version: Union[_Missing, distutils.version.StrictVersion] = missing,
         # RDF
         attachments: Union[_Missing, Dict[str, Any]] = missing,
-        authors: List[Author],
+        authors: Union[_Missing, List[Author]] = missing,
         badges: Union[_Missing, List[Badge]] = missing,
-        cite: List[CiteEntry],
+        cite: Union[_Missing, List[CiteEntry]] = missing,
         config: Union[_Missing, dict] = missing,
         covers: Union[_Missing, List[Union[URI, Path]]] = missing,
         description: str,
-        documentation: Path,
+        documentation: Union[_Missing, Path, URI] = missing,
+        download_url: Union[_Missing, URI] = missing,
         git_repo: Union[_Missing, str] = missing,
+        id: Union[_Missing, str] = missing,
+        icon: Union[_Missing, str] = missing,
         license: Union[_Missing, str] = missing,
         links: Union[_Missing, List[str]] = missing,
         maintainers: Union[_Missing, List[Maintainer]] = missing,
-        tags: List[str],
+        rdf_source: Union[_Missing, URI] = missing,
+        tags: Union[_Missing, List[str]] = missing,
         **unknown_kwargs,
     ):
         self.attachments = attachments
@@ -121,18 +136,23 @@ class RDF(ResourceDescription):
         self.covers = covers
         self.description = description
         self.documentation = documentation
+        self.download_url = download_url
         self.git_repo = git_repo
+        self.id = id
+        self.icon = icon
         self.license = license
         self.links = links
         self.maintainers = maintainers
+        self.rdf_source = rdf_source
         self.tags = tags
         super().__init__(format_version=format_version, name=name, type=type, version=version)
 
         if unknown_kwargs:
             # make sure we didn't forget a defined field
             field_names = set(f.name for f in dataclasses.fields(self))
+            field_names.remove("root_path")  # ignore internal root_path field
             for uk in unknown_kwargs:
-                assert uk not in field_names
+                assert uk not in field_names, uk
 
             warnings.warn(f"discarding unknown RDF fields: {unknown_kwargs}")
 
