@@ -57,8 +57,8 @@ class Badge(_BioImageIOSchema):
 
 class CiteEntry(_BioImageIOSchema):
     text = fields.String(required=True)
-    doi = fields.String(bioimageio_maybe_required=True)
-    url = fields.String(bioimageio_maybe_required=True)
+    doi = fields.DOI(bioimageio_maybe_required=True)
+    url = fields.String(bioimageio_maybe_required=True)  # todo: change to fields.URL
 
     @validates_schema
     def doi_or_url(self, data, **kwargs):
@@ -88,14 +88,14 @@ specified.
     authors_bioimageio_description = (
         "A list of authors. The authors are the creators of the specifications and the primary points of contact."
     )
-    authors = fields.List(fields.Nested(Author()), bioimageio_description=authors_bioimageio_description, required=True)
+    authors = fields.List(fields.Nested(Author()), bioimageio_description=authors_bioimageio_description)
 
     badges = fields.List(fields.Nested(Badge()), bioimageio_description="a list of badges")
 
     cite_bioimageio_description = """A list of citation entries.
 Each entry contains a mandatory `text` field and either one or both of `doi` and `url`.
 E.g. the citation for the model architecture and/or the training data used."""
-    cite = fields.List(fields.Nested(CiteEntry()), required=True, bioimageio_description=cite_bioimageio_description)
+    cite = fields.List(fields.Nested(CiteEntry()), bioimageio_description=cite_bioimageio_description)
 
     config_bioimageio_description = (
         "A custom configuration field that can contain any keys not present in the RDF spec. "
@@ -139,12 +139,11 @@ E.g. the citation for the model architecture and/or the training data used."""
                 )
             ),
         ],
-        required=True,
         bioimageio_description="URL or relative path to markdown file with additional documentation. "
         "For markdown files the recommended documentation file name is `README.md`.",
     )
 
-    download_url = fields.URL(bioimageio_description="recommended url to the zipped file if applicable")
+    download_url = fields.URL(bioimageio_description="optional url to download the resource from")
 
     format_version = fields.String(
         required=True,
@@ -176,6 +175,7 @@ E.g. the citation for the model architecture and/or the training data used."""
         bioimageio_description="an icon for the resource"
     )  # todo: limit length? validate=field_validators.Length(max=1)
 
+    id = fields.String(bioimageio_description="Unique id within a collection of resources.")
     license_bioimageio_description = (
         "A [SPDX license identifier](https://spdx.org/licenses/)(e.g. `CC-BY-4.0`, `MIT`, "
         "`BSD-2-Clause`). We don't support custom license beyond the SPDX license list, if you need that please send "
@@ -214,12 +214,15 @@ E.g. the citation for the model architecture and/or the training data used."""
         else:
             self.warn("name", f"Could not check length of name {value}.")
 
+    rdf_source = fields.Union(
+        [fields.URL(), fields.DOI()], bioimageio_description="url or doi to the source of the resource definition"
+    )
     source = fields.Union(
         [fields.URI(), fields.RelativeLocalPath()],
         bioimageio_description="url or local relative path to the source of the resource",
     )
 
-    tags = fields.List(fields.String(), required=True, bioimageio_description="A list of tags.")
+    tags = fields.List(fields.String(), bioimageio_description="A list of tags.")
 
     type = fields.String(required=True)
 
