@@ -7,7 +7,7 @@ import typing
 
 import marshmallow_union
 import numpy
-from marshmallow import ValidationError, fields as marshmallow_fields, Schema
+from marshmallow import Schema, ValidationError, fields as marshmallow_fields, missing
 
 from . import field_validators, raw_nodes
 
@@ -119,13 +119,23 @@ class YamlDict(Dict):
     @staticmethod
     def _make_yaml_friendly(obj):
         if isinstance(obj, (list, tuple)):
-            return [YamlDict._make_yaml_friendly(ob) for ob in obj]
+            return [YamlDict._make_yaml_friendly(ob) for ob in obj if ob is not missing]
         elif isinstance(obj, dict):
-            return {YamlDict._make_yaml_friendly(k): YamlDict._make_yaml_friendly(v) for k, v in obj.items()}
+            return {
+                YamlDict._make_yaml_friendly(k): YamlDict._make_yaml_friendly(v)
+                for k, v in obj.items()
+                if v is not missing
+            }
         elif obj is None or isinstance(obj, (float, int, str, bool)):
             return obj
         elif isinstance(obj, pathlib.PurePath):
             return obj.as_posix()
+        elif isinstance(obj, raw_nodes.URI):
+            return str(obj)
+        elif isinstance(obj, (datetime.datetime, datetime.time)):
+            return obj.isoformat()
+        elif obj is missing:
+            return missing
         else:
             raise TypeError(f"Encountered YAML unfriendly type: {type(obj)}")
 
@@ -134,6 +144,20 @@ class YamlDict(Dict):
         return super()._serialize(value, attr, obj, **kwargs)
 
 
+class RDF_Update(YamlDict):
+    def __init__(
+        self,
+        keys: typing.Optional[DocumentedField] = None,
+        values: typing.Optional[DocumentedField] = None,
+        *args,
+        **kwargs,
+    ):
+        if keys is None:
+            keys = String(bioimageio_description="RDF field names to overwrite")
+
+        super().__init__(keys, values, *args, **kwargs)
+
+
 class Email(DocumentedField, marshmallow_fields.Email):
     pass
 
@@ -192,6 +216,10 @@ class String(DocumentedField, marshmallow_fields.String):
     pass
 
 
+class DOI(String):
+    pass
+
+
 class Tuple(DocumentedField, marshmallow_fields.Tuple):
     def __init__(self, tuple_fields: typing.Sequence[DocumentedField], *args, **kwargs):
         assert all(isinstance(tf, DocumentedField) for tf in tuple_fields)
