@@ -35,10 +35,9 @@ class SharedBioImageIOSchema(Schema):
 
     def warn(self, field: str, msg: str):
         """warn about a field with a ValidationWarning"""
-        simple_field_name = field.split("[")[0]  # field may include [idx] or [key]
-        field_instance = self.fields[simple_field_name]
-        assert ":" not in field
-        assert " " not in field
+        simple_field_name = field.split("[")[0]  # field may include [idx]
+        # field_instance = self.fields[simple_field_name]  # todo: account for <field>:<nested field>
+        assert ": " not in field
         # todo: add spec trail to field
         # e.g. something similar to field = ":".join(self.context.get("field_path", []) + [field])
         # or: ":".join(field_instance.spec_trail)
@@ -58,20 +57,25 @@ class SharedProcessingSchema(Schema):
 class WithUnknown(SharedBioImageIOSchema):
     """allows to keep unknown fields on load and dump them the 'unknown' attribute of the data to serialize"""
 
+    field_name_unknown_dict = "unknown"
+
     class Meta:
         unknown = INCLUDE
 
     @post_load
     def make_object(self, data, **kwargs):
         obj = super().make_object(data, **kwargs)
-        assert hasattr(obj, "unknown")  # expected raw node to have attribute "unknown"
+        assert hasattr(
+            obj, self.field_name_unknown_dict
+        ), f"expected raw node to have attribute {self.field_name_unknown_dict}"
         return obj
 
     @post_dump(pass_original=True)
     def keep_unknowns(self, output, orig, **kwargs):
-        if orig:
-            assert hasattr(orig, "unknown")  # expected raw node to have attribute "unknown"
-            out_w_unknown = dict(orig.unknown)
+        if orig and hasattr(orig, self.field_name_unknown_dict):
+            out_w_unknown = fields.YamlDict()._serialize(
+                getattr(orig, self.field_name_unknown_dict), self.field_name_unknown_dict, self
+            )
             out_w_unknown.update(output)
             return out_w_unknown
         else:
